<?php


namespace app\admin\controller;

use app\admin\validate\Category as CategoryValidate;
use app\common\business\Category as CategoryBusiness;
use app\common\lib\Status as StatusLib;
use think\facade\View;


class Category extends AdminBase
{
    /**
     * @return string
     * @throws \Exception
     */
    public function index()
    {
        $pid = input('param.id', 0, 'intval');
        $data = [
            "pid" => $pid
        ];
        try {
            $categorys = (new CategoryBusiness())->getLists($data, 5);
        } catch (\Exception $e) {
            $categorys = [];
        }

        return View::fetch('', [
            'categorys' => $categorys
        ]);
    }

    /**
     * @return string
     * @throws \Exception
     */
    public function add()
    {
        try {
            $categorys = (new CategoryBusiness)->getNormalCategory();
        } catch (\Exception $e) {
            $categorys = [];
        }

        return View::fetch('', [
            'categorys' => json_encode($categorys)
        ]);
    }

    /**
     * 新增
     * @return \think\response\Json
     */
    public function save()
    {
        $pid = input("param.pid", 0, "intval");
        $name = input("param.name", '', "trim");

        // 参数校验
        $data = [
            'pid' => $pid,
            'name' => $name
        ];
        $validate = new CategoryValidate();
        if (!$validate->check($data)) {
            return show(config('status.error'), $validate->getError());
        }

        try {
            $id = (new CategoryBusiness)->add($data);
        } catch (\Exception $e) {
            return show(config('status.error'), $e->getMessage());
        }
        if ($id) {
            return show(config('status.success'), 'OK');
        }
        return show(config('status.error'), '新增分类失败');
    }

    public function listorder()
    {
        $id = input('param.id', 0, 'intval');
        $listorder = input('param.listorder', 0, 'intval');

        if (!$id) {
            return show(config('status.error'), '参数错误');
        }

        try {
            $res = (new CategoryBusiness())->listorder($id, $listorder);
        } catch (\Exception $e) {
            return show(config('status.error'), $e->getMessage());
        }
        if ($res) {
            return show(config('status.success'), '排序成功');
        } else {
            return show(config('status.error'), '排序失败');
        }
    }

    public function status()
    {
        $id = input('param.id', 0, 'intval');
        $status = input('param.status', 0, 'intval');

        if (!$id || !in_array($status, StatusLib::getTableStatus())) {
            return show(config('status.error'), '参数错误');
        }

        try {
            $res = (new CategoryBusiness())->status($id, $status);
        } catch (\Exception $e) {
            return show(config('status.error'), $e->getMessage());
        }
        if ($res) {
            return show(config('status.success'), '状态更新成功');
        } else {
            return show(config('status.error'), '状态更新失败');
        }
    }
}