<?php
declare(strict_types=1);

namespace app\common\business;

use app\common\model\mysql\Category as CategoryModel;

class Category
{
    public $model = null;

    public function __construct()
    {
        $this->model = new CategoryModel();
    }

    /**
     * 新增一条分类
     * @param array $data
     * @return mixed
     * @throws \think\Exception
     */
    public function add(array $data)
    {
        $data['status'] = config('status.mysql.table_normal');

        $name = $data['name'];
        $count = $this->model->where('name', $name)->count();
        if ($count > 0) {
            throw new \think\Exception('分类名已经存在');
        }

        try {
            $this->model->save($data);
        } catch (\Exception $e) {
            throw new \think\Exception('服务内部异常');
        }
        return $this->model->id;
    }

    /**
     * 获取正常状态的分类
     * @return array|\think\Collection
     * @throws \think\db\exception\DataNotFoundException
     * @throws \think\db\exception\DbException
     * @throws \think\db\exception\ModelNotFoundException
     */
    public function getNormalCategory()
    {
        $field = "id, name, pid";
        $categorys = $this->model->getNormalCategory($field);
        if (!$categorys) {
            return [];
        }
        $categorys = $categorys->toArray();
        return $categorys;
    }

    /**
     * 分页获取分类列表
     * @param $data
     * @param $num
     * @return array
     * @throws \think\db\exception\DbException
     */
    public function getLists($data, $num)
    {
        $list = $this->model->getLists($data, $num);
        if (!$list) {
            return [];
        }
        $result = $list->toArray();
        $result['render'] = $list->render();
        return $result;
    }

    /**
     * 根据id获取某一条记录
     * @param $id
     * @return array|\think\Model|null
     * @throws \think\db\exception\DataNotFoundException
     * @throws \think\db\exception\DbException
     * @throws \think\db\exception\ModelNotFoundException
     */
    public function getById($id)
    {
        $result = $this->model->find($id);
        if (empty($result)) {
            return [];
        }
        $result = $result->toArray();
        return $result;
    }

    /**
     * 修改分类表排序的值
     * @param $id
     * @param $listorder
     * @return array|bool|\think\Model|null
     * @throws \think\Exception
     * @throws \think\db\exception\DataNotFoundException
     * @throws \think\db\exception\DbException
     * @throws \think\db\exception\ModelNotFoundException
     */
    public function listorder($id, $listorder)
    {
        $res = $this->getById($id);
        if (!$res) {
            throw new \think\Exception('不存在该条记录');
        }
        $data = [
            'listorder' => $listorder
        ];

        try {
            $res = $this->model->updateById($id, $data);
        } catch (\Exception $e) {
            // 记录日志
            return false;
        }

        return $res;
    }

    /**
     * 分类状态值修改
     * @param $id
     * @param $status
     * @return array|bool|\think\Model|null
     * @throws \think\Exception
     * @throws \think\db\exception\DataNotFoundException
     * @throws \think\db\exception\DbException
     * @throws \think\db\exception\ModelNotFoundException
     */
    public function status($id, $status)
    {
        $res = $this->getById($id);
        if (!$res) {
            throw new \think\Exception('不存在该条记录');
        }
        if ($res['status'] == $status) {
            throw new \think\Exception('状态修改前后无区别');
        }

        $data = [
            'status' => (int)$status
        ];
        try {
            $res = $this->model->updateById($id, $data);
        } catch (\Exception $e) {
            // 记录日志
            return false;
        }
        return $res;
    }
}